@@ -19,9 +19,9 @@ client = 'portal'
 sampling = FALSE
 sample_rgts = c("24", "32")
 
-INVALID_URL = "https://openaltimetry.org/INVALID/"
-VALID_URL_a3 = glue::glue("https://openaltimetry.org/data/api/icesat2/{product}?minx={minx}&miny={miny}&maxx={maxx}&maxy={maxy}&trackId={trackId}&beamName={beamName}&outputFormat={outputFormat}&date={date}&client={client}&sampling={tolower(sampling)}")
-VALID_URL_remaining = glue::glue("https://openaltimetry.org/data/api/icesat2/{product}?minx={minx}&miny={miny}&maxx={maxx}&maxy={maxy}&trackId={trackId}&outputFormat={outputFormat}&date={date}&client={client}&beamName={beamName}")
+INVALID_URL = "https://openaltimetry.earthdatacloud.nasa.gov/INVALID/"
+VALID_URL_a3 = glue::glue("https://openaltimetry.earthdatacloud.nasa.gov/data/api/icesat2/{product}?minx={minx}&miny={miny}&maxx={maxx}&maxy={maxy}&trackId={trackId}&beamNames={beamName}&outputFormat={outputFormat}&date={date}&client={client}&sampling={tolower(sampling)}")
+VALID_URL_remaining = glue::glue("https://openaltimetry.earthdatacloud.nasa.gov/data/api/icesat2/{product}?minx={minx}&miny={miny}&maxx={maxx}&maxy={maxy}&trackId={trackId}&outputFormat={outputFormat}&date={date}&client={client}&beamNames={beamName}")
 ORBITS_URL = 'https://icesat-2.gsfc.nasa.gov/sites/default/files/page_files/arcticallorbits.zip'
 WKT = 'POLYGON ((-14.765 18.979, -11.25 18.979, -11.25 21.943, -14.765 21.943, -14.765 18.979))'
 
